@@ -1,59 +1,59 @@
 $VAR1 = {
-          'version' => '1.15',
           'files' => {
                        'owner' => 'www-data',
-                       'chmod' => '0755',
-                       'group' => 'www-data'
+                       'group' => 'www-data',
+                       'chmod' => '0755'
+                     },
+          'admin' => {
+                       'password' => 'testpass'
                      },
           'database' => {
-                          'host' => 'localhost',
-                          'CurrentPass' => '',
-                          'CurrentHost' => 'localhost',
-                          'CurrentUser' => 'lze',
                           'password' => '',
+                          'CurrentHost' => 'localhost',
+                          'CurrentPass' => '',
+                          'name' => 'lze',
+                          'host' => 'localhost',
+                          'CurrentUser' => 'lze',
                           'user' => 'lze',
-                          'CurrentDb' => 'lze',
-                          'name' => 'lze'
+                          'CurrentDb' => 'lze'
                         },
-          'htmlright' => '2',
-          'mod' => 'n',
+          'config' => '/var/www/cgi-bin/config/settings.pl',
           'tree' => {
                       'navigation' => '/var/www/cgi-bin/config/tree.pl',
                       'links' => '/var/www/cgi-bin/config/links.pl'
                     },
-          'language' => 'en',
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'uploads' => {
-                         'right' => 2,
-                         'path' => '/var/www/html//download',
-                         'enabled' => 1,
-                         'chmod' => 438,
-                         'maxlength' => '2100000000000000'
-                       },
-          'saveTranslate' => '0',
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'floodtime' => 10,
           'cgi' => {
-                     'bin' => '/var/www/cgi-bin',
-                     'serverName' => 'http://localhost',
-                     'DocumentRoot' => '/var/www/html/',
                      'cookiePath' => '/',
-                     'expires' => '+1y',
                      'style' => 'mysql',
-                     'title' => 'MySQL::Admin'
+                     'DocumentRoot' => '/var/www/html/',
+                     'serverName' => 'http://localhost',
+                     'title' => 'MySQL::Admin',
+                     'expires' => '+1y',
+                     'bin' => '/var/www/cgi-bin'
                    },
-          'size' => '16',
-          'admin' => {
-                       'password' => 'testpass'
-                     },
-          'defaultAction' => 'ShowDatabases',
+          'saveTranslate' => '0',
+          'uploads' => {
+                         'maxlength' => '2100000000000000',
+                         'path' => '/var/www/html//download',
+                         'right' => 2,
+                         'chmod' => 438,
+                         'enabled' => 1
+                       },
           'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'floodtime' => 10,
+          'language' => 'en',
+          'size' => '16',
           'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'version' => '1.14',
+          'htmlright' => '2',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'defaultAction' => 'ShowDatabases',
+          'mod' => 'n',
           'news' => {
                       'right' => 5,
                       'messages' => '5',
                       'captcha' => 3
-                    },
-          'config' => '/var/www/cgi-bin/config/settings.pl'
+                    }
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
