@@ -432,7 +432,7 @@ function requestURI(url, id, txt, bHistory, formData, method, bWaid) {
             } catch (e) {}
         }
     }
-    //     setCurrentTab(id,txt);
+
     m_txt = txt;
     visible('load');
     http_request.onreadystatechange = setContent;
@@ -441,7 +441,6 @@ function requestURI(url, id, txt, bHistory, formData, method, bWaid) {
         http_request.send(null);
     } else {
         http_request.open('POST', url, true);
-        http_request.setRequestHeader("Accept-Encoding", "UTF-8");
         http_request.setRequestHeader("Content-Type", "multipart/form-data");
         http_request.send(formData);
     }
@@ -1655,4 +1654,4 @@ function checkButton(id,parent){
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
     See the GNU Lesser General Public License for more details
 =cut
-*/
\ No newline at end of file
+*/
